==> qtmobilehotspot_0.3.1.tar.gz: qtmobilehotspot-0.3.1/qtmhIptablesFix/libqtmhiptablesfix-fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>MobileHotspotConfiguration</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="src/plugin.cpp" line="33"/>
        <source>Iptables Tweaker</source>
        <translation>Perso Iptables</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="52"/>
        <source>Configure</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="52"/>
        <source>Please stop the hotspot before configuring.</source>
        <translation>Veuillez arrêter le hotspot avant de configurer.</translation>
    </message>
</context>
<context>
    <name>PluginGUIClass</name>
    <message>
        <location filename="src/plugingui.ui" line="14"/>
        <source>Iptables...</source>
        <translation>Iptables...</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="24"/>
        <source>Enter your iptables rules (see Default).</source>
        <translation>Entrez vos règles iptables (voir Défaut).</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="31"/>
        <source>Masks : $NETIF$, $LANIF$, $LANNET$</source>
        <translation>Masques : $NETIF$, $LANIF$, $LANNET$</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="38"/>
        <source>$LANIP$, $LANBROAD$, $LANMAC$</source>
        <translation>$LANIP$, $LANBROAD$, $LANMAC$</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="79"/>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
</context>
</TS>

==> qtmobilehotspot_0.3.2.tar.gz: qtmobilehotspot-0.3.2/qtmhIptablesFix/libqtmhiptablesfix-fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>MobileHotspotConfiguration</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="src/plugin.cpp" line="33"/>
        <source>Iptables Tweaker</source>
        <translation>Perso Iptables</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="52"/>
        <source>Configure</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="52"/>
        <source>Please stop the hotspot before configuring.</source>
        <translation>Veuillez arrêter le hotspot avant de configurer.</translation>
    </message>
</context>
<context>
    <name>PluginGUI</name>
    <message>
        <location filename="src/plugingui.cpp" line="39"/>
        <location filename="src/plugingui.cpp" line="52"/>
        <source>Select a file...</source>
        <translation>Choisissez un fichier...</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="44"/>
        <location filename="src/plugingui.cpp" line="57"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="44"/>
        <location filename="src/plugingui.cpp" line="57"/>
        <source>Cannot open the selected file</source>
        <translation>Impossible d&apos;ouvrir le fichier choisi</translation>
    </message>
</context>
<context>
    <name>PluginGUIClass</name>
    <message>
        <location filename="src/plugingui.ui" line="14"/>
        <location filename="src/ui_plugingui.h" line="167"/>
        <source>Iptables...</source>
        <translation>Iptables...</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="24"/>
        <location filename="src/ui_plugingui.h" line="168"/>
        <source>Enter your iptables rules (see Default).</source>
        <translation>Entrez vos règles iptables (voir Défaut).</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="31"/>
        <location filename="src/ui_plugingui.h" line="169"/>
        <source>Masks : $NETIF$, $LANIF$, $LANNET$</source>
        <translation>Masques : $NETIF$, $LANIF$, $LANNET$</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="38"/>
        <location filename="src/ui_plugingui.h" line="170"/>
        <source>$LANIP$, $LANBROAD$, $LANMAC$</source>
        <translation>$LANIP$, $LANBROAD$, $LANMAC$</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="83"/>
        <location filename="src/ui_plugingui.h" line="171"/>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="103"/>
        <location filename="src/ui_plugingui.h" line="172"/>
        <source>Load...</source>
        <translation>Ouvrir...</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="110"/>
        <location filename="src/ui_plugingui.h" line="173"/>
        <source>Save...</source>
        <translation>Sauver...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
</context>
</TS>
